@@ -1,7 +1,8 @@
 # LOGISTIC REGRESSION
 difLogistic<-function (Data, group, focal.name, type="both", criterion="LRT",alpha = 0.05, 
-    purify = FALSE, nrIter = 10) 
+    purify = FALSE, nrIter = 10,save.output=FALSE, output=c("out","default")) 
 {
+internalLog<-function(){
     if (length(group) == 1) {
         if (is.numeric(group) == TRUE) {
             gr <- Data[, group]
@@ -41,7 +42,7 @@ difLogistic<-function (Data, group, focal.name, type="both", criterion="LRT",alp
 		}
         RES <- list(Logistik = STATS, logitPar = logitPar, deltaR2 = deltaR2,
 		alpha = alpha, thr = Q, DIFitems = DIFitems, type = type,
-		purification = purify, names = colnames(DATA), criterion=criterion)
+		purification = purify, names = colnames(DATA), criterion=criterion,save.output=save.output,output=output)
     }
     else {
         nrPur <- 0
@@ -113,17 +114,27 @@ difLogistic<-function (Data, group, focal.name, type="both", criterion="LRT",alp
         RES <- list(Logistik = stats1, logitPar = logitPar, deltaR2 = deltaR2,
 		alpha = alpha, thr = Q, DIFitems = DIFitems, type = type,
 		purification = purify, nrPur = nrPur, difPur = difPur, 
-		convergence = noLoop, names = colnames(DATA),criterion=criterion)
+		convergence = noLoop, names = colnames(DATA),criterion=criterion,save.output=save.output,output=output)
     }
     class(RES) <- "Logistic"
     return(RES)
 }
+resToReturn<-internalLog()
+if (save.output==TRUE){
+if (output[2]=="default") wd<-paste(getwd(),"/",sep="")
+else wd<-output[2]
+fileName<-paste(wd,output[1],".txt",sep="")
+capture.output(resToReturn,file=fileName)
+}
+return(resToReturn)
+}
 
 
 # METHODS
 plot.Logistic <- function (x, plot = "lrStat", item = 1, pch = 8, number = TRUE, col = "red", 
-colIC = rep("black",2), ltyIC = c(1,2), ...) 
+colIC = rep("black",2), ltyIC = c(1,2), save.plot=FALSE,save.options=c("plot","default","pdf"),...)  
 {
+internalLog<-function(){
     res <- x
     plotType <- switch(plot, lrStat=1, itemCurve=2)
     if (is.null(plotType)==TRUE) return("Error: misspecified 'type' argument")
@@ -167,6 +178,37 @@ colIC = rep("black",2), ltyIC = c(1,2), ...)
 	}
     }
 }
+internalLog()
+if (save.plot==TRUE){
+plotype<-NULL
+if (save.options[3]=="pdf") plotype<-1
+if (save.options[3]=="jpeg") plotype<-2
+if (is.null(plotype)==TRUE) cat("Invalid plot type (should be either 'pdf' or 'jpeg').","\n","The plot was not captured!","\n")
+else {
+if (save.options[2]=="default") wd<-paste(getwd(),"/",sep="")
+else wd<-save.options[2]
+fileName<-paste(wd,save.options[1],switch(plotype,'1'=".pdf",'2'=".jpg"),sep="")
+if (plotype==1){
+{
+pdf(file=fileName)
+internalLog()
+}
+dev.off()
+}
+if (plotype==2){
+{
+jpeg(file=fileName)
+internalLog()
+}
+dev.off()
+}
+cat("The plot was captured and saved into","\n"," '",fileName,"'","\n","\n",sep="")
+}
+}
+else cat("The plot was not captured!","\n",sep="")
+}
+
+
 
 print.Logistic <- function (x, ...) 
 {
@@ -266,5 +308,12 @@ print.Logistic <- function (x, ...)
     cat("Effect size codes:", "\n")
     cat(" Zumbo & Thomas (ZT): 0 'A' 0.13 'B' 0.26 'C' 1","\n")
     cat(" Jodoign & Gierl (JG): 0 'A' 0.035 'B' 0.07 'C' 1","\n")
+if (x$save.output==FALSE) cat("\n","Output was not captured!","\n")
+    else {
+if (x$output[2]=="default") wd<-paste(getwd(),"/",sep="")
+else wd<-x$output[2]
+fileName<-paste(wd,x$output[1],".txt",sep="")
+cat("\n","Output was captured and saved into file","\n"," '",fileName,"'","\n","\n",sep="")
+}
 }
 
